<TS language="ca" version="2.0">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Create a new address</source>
        <translation>Crea una nova adreça</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Nova</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation>Copia l'adreça seleccionada al porta-retalls del sistema</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp;Copia</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation>Elimina l'adreça sel·leccionada actualment de la llista</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;Elimina</translation>
    </message>
    <message>
        <source>Copy &amp;Label</source>
        <translation>Copia l'eti&amp;queta</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Edita</translation>
    </message>
    </context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Label</source>
        <translation>Etiqueta</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Adreça</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(sense etiqueta)</translation>
    </message>
</context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Passphrase Dialog</source>
        <translation>Diàleg de contrasenya</translation>
    </message>
    <message>
        <source>Enter passphrase</source>
        <translation>Introduïu una contrasenya</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation>Nova contrasenya</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation>Repetiu la nova contrasenya</translation>
    </message>
    <message>
        <source>Enter the new passphrase to the wallet.&lt;br/&gt;Please use a passphrase of &lt;b&gt;ten or more random characters&lt;/b&gt;, or &lt;b&gt;eight or more words&lt;/b&gt;.</source>
        <translation>Introduïu la contrasenya nova al moneder.&lt;br/&gt;Utilitzeu una contrasenya de &lt;b&gt;deu o més caràcters aleatoris&lt;/b&gt;, o &lt;b&gt;vuit o més paraules&lt;/b&gt;.</translation>
    </message>
    <message>
        <source>Encrypt wallet</source>
        <translation>Encripta el moneder</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to unlock the wallet.</source>
        <translation>Aquesta operació requereix la contrasenya del moneder per a desbloquejar-lo.</translation>
    </message>
    <message>
        <source>Unlock wallet</source>
        <translation>Desbloqueja el moneder</translation>
    </message>
    <message>
        <source>Change passphrase</source>
        <translation>Canvia la contrasenya</translation>
    </message>
    <message>
        <source>Enter the old and new passphrase to the wallet.</source>
        <translation>Introduïu l'antiga i la nova frase-contrasenya per a la cartera.</translation>
    </message>
    <message>
        <source>Confirm wallet encryption</source>
        <translation>Confirma l'encriptació del moneder</translation>
    </message>
    <message>
        <source>Are you sure you wish to encrypt your wallet?</source>
        <translation>Esteu segur que voleu encriptar el vostre moneder?</translation>
    </message>
    <message>
        <source>Wallet encrypted</source>
        <translation>Moneder encriptat</translation>
    </message>
    <message>
        <source>IMPORTANT: Any previous backups you have made of your wallet file should be replaced with the newly generated, encrypted wallet file. For security reasons, previous backups of the unencrypted wallet file will become useless as soon as you start using the new, encrypted wallet.</source>
        <translation>IMPORTANT: Tota copia de seguretat que hàgiu realitzat hauria de ser reemplaçada pel, recentment generat, fitxer encriptat del moneder. Per motius de seguretat, les còpies de seguretat anteriors del fitxer de moneder no encriptat esdevindran inusables tan aviat com començar a utilitzar el nou moneder encriptat.</translation>
    </message>
    <message>
        <source>Wallet encryption failed</source>
        <translation>L'encriptació del moneder ha fallat</translation>
    </message>
    <message>
        <source>Wallet encryption failed due to an internal error. Your wallet was not encrypted.</source>
        <translation>L'encriptació del moneder ha fallat per un error intern. El moneder no ha estat encriptat.</translation>
    </message>
    <message>
        <source>The supplied passphrases do not match.</source>
        <translation>Les contrasenyes introduïdes no coincideixen.</translation>
    </message>
    <message>
        <source>Wallet unlock failed</source>
        <translation>El desbloqueig del moneder ha fallat</translation>
    </message>
    <message>
        <source>The passphrase entered for the wallet decryption was incorrect.</source>
        <translation>La contrasenya introduïda per a desencriptar el moneder és incorrecta.</translation>
    </message>
    <message>
        <source>Wallet passphrase was successfully changed.</source>
        <translation>La contrasenya del moneder ha estat modificada correctament.</translation>
    </message>
    <message>
        <source>Warning: The Caps Lock key is on!</source>
        <translation>Avís: Les lletres majúscules estan activades!</translation>
    </message>
</context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>Wallet</source>
        <translation>Moneder</translation>
    </message>
    <message>
        <source>&amp;Overview</source>
        <translation>&amp;Panorama general</translation>
    </message>
    <message>
        <source>Show general overview of wallet</source>
        <translation>Mostra el panorama general del moneder</translation>
    </message>
    <message>
        <source>&amp;Send</source>
        <translation>&amp;Envia</translation>
    </message>
    <message>
        <source>&amp;Receive</source>
        <translation>&amp;Rep</translation>
    </message>
    <message>
        <source>Browse transaction history</source>
        <translation>Cerca a l'historial de transaccions</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>S&amp;urt</translation>
    </message>
    <message>
        <source>Quit application</source>
        <translation>Surt de l'aplicació</translation>
    </message>
    <message>
        <source>&amp;Options...</source>
        <translation>&amp;Opcions...</translation>
    </message>
    <message>
        <source>&amp;Show / Hide</source>
        <translation>&amp;Mostra / Amaga</translation>
    </message>
    <message>
        <source>&amp;Encrypt Wallet...</source>
        <translation>&amp;Encripta el moneder...</translation>
    </message>
    <message>
        <source>&amp;Change Passphrase...</source>
        <translation>&amp;Canvia la contrasenya...</translation>
    </message>
    <message>
        <source>Change the passphrase used for wallet encryption</source>
        <translation>Canvia la contrasenya d'encriptació del moneder</translation>
    </message>
    <message>
        <source>Sign &amp;message...</source>
        <translation>Signa el &amp;missatge...</translation>
    </message>
    <message>
        <source>&amp;Verify message...</source>
        <translation>&amp;Verifica el missatge...</translation>
    </message>
    <message>
        <source>&amp;Debug window</source>
        <translation>&amp;Finestra de depuració</translation>
    </message>
    <message>
        <source>Open debugging and diagnostic console</source>
        <translation>Obre la consola de diagnòstic i depuració</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Fitxer</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Configuració</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Ajuda</translation>
    </message>
    <message numerus="yes">
        <source>%n active connection(s) to the Gridcoin network</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>Processed %n block(s) of transaction history.</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n second(s) ago</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s) ago</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s) ago</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n day(s) ago</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Up to date</source>
        <translation>Al dia</translation>
    </message>
    <message>
        <source>Catching up...</source>
        <translation>S'està posant al dia ...</translation>
    </message>
    <message>
        <source>Sent transaction</source>
        <translation>Transacció enviada</translation>
    </message>
    <message>
        <source>Incoming transaction</source>
        <translation>Transacció entrant</translation>
    </message>
    <message>
        <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;locked&lt;/b&gt;</source>
        <translation>El moneder està &lt;b&gt;encriptat&lt;/b&gt; i actualment &lt;b&gt;bloquejat&lt;/b&gt;</translation>
    </message>
    </context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>Quantity:</source>
        <translation>Quantitat:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>Import:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation>Comissió:</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation>Comissió posterior:</translation>
    </message>
    <message>
        <source>Change:</source>
        <translation>Canvi:</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Import</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Data</translation>
    </message>
    <message>
        <source>Confirmations</source>
        <translation>Confirmacions</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>Confirmat</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Adreça</translation>
    </message>
    <message>
        <source>Copy address</source>
        <translation>Copia l'adreça</translation>
    </message>
    <message>
        <source>Copy label</source>
        <translation>Copia l'etiqueta</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>Copia l'import</translation>
    </message>
    <message>
        <source>Copy transaction ID</source>
        <translation>Copia l'ID de transacció</translation>
    </message>
    <message>
        <source>Copy quantity</source>
        <translation>Copia la quantitat</translation>
    </message>
    <message>
        <source>Copy fee</source>
        <translation>Copia la comissió</translation>
    </message>
    <message>
        <source>Copy after fee</source>
        <translation>Copia la comissió posterior</translation>
    </message>
    <message>
        <source>Copy bytes</source>
        <translation>Copia els bytes</translation>
    </message>
    <message>
        <source>Copy change</source>
        <translation>Copia el canvi</translation>
    </message>
    <message>
        <source>yes</source>
        <translation>sí</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(sense etiqueta)</translation>
    </message>
    <message>
        <source>change from %1 (%2)</source>
        <translation>canvia de %1 (%2)</translation>
    </message>
    <message>
        <source>(change)</source>
        <translation>(canvia)</translation>
    </message>
</context>
<context>
    <name>EditAddressDialog</name>
    <message>
        <source>Edit Address</source>
        <translation>Edita l'adreça</translation>
    </message>
    <message>
        <source>&amp;Label</source>
        <translation>&amp;Etiqueta</translation>
    </message>
    <message>
        <source>&amp;Address</source>
        <translation>&amp;Adreça</translation>
    </message>
    <message>
        <source>New receiving address</source>
        <translation>Nova adreça de recepció</translation>
    </message>
    <message>
        <source>New sending address</source>
        <translation>Nova adreça d'enviament</translation>
    </message>
    <message>
        <source>Edit receiving address</source>
        <translation>Edita l'adreça de recepció</translation>
    </message>
    <message>
        <source>Edit sending address</source>
        <translation>Edita l'adreça d'enviament</translation>
    </message>
    <message>
        <source>The entered address "%1" is already in the address book.</source>
        <translation>L'adreça introduïda «%1» ja és present a la llibreta d'adreces.</translation>
    </message>
    <message>
        <source>Could not unlock wallet.</source>
        <translation>No s'ha pogut desbloquejar el moneder.</translation>
    </message>
    <message>
        <source>New key generation failed.</source>
        <translation>Ha fallat la generació d'una clau nova.</translation>
    </message>
</context>
<context>
    <name>Intro</name>
    <message numerus="yes">
        <source>%n GB of free space available</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>(of %n GB needed)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>(%n GB needed for full chain)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
</context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Options</source>
        <translation>Opcions</translation>
    </message>
    <message>
        <source>&amp;Main</source>
        <translation>&amp;Principal</translation>
    </message>
    <message>
        <source>&amp;Network</source>
        <translation>&amp;Xarxa</translation>
    </message>
    <message>
        <source>Map port using &amp;UPnP</source>
        <translation>Port obert amb &amp;UPnP</translation>
    </message>
    <message>
        <source>Port of the proxy (e.g. 9050)</source>
        <translation>Port del proxy (per exemple 9050)</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation>&amp;Finestra</translation>
    </message>
    <message>
        <source>Show only a tray icon after minimizing the window.</source>
        <translation>Mostra només la icona de la barra en minimitzar la finestra.</translation>
    </message>
    <message>
        <source>&amp;Minimize to the tray instead of the taskbar</source>
        <translation>&amp;Minimitza a la barra d'aplicacions en comptes de la barra de tasques</translation>
    </message>
    <message>
        <source>M&amp;inimize on close</source>
        <translation>M&amp;inimitza en tancar</translation>
    </message>
    <message>
        <source>&amp;Display</source>
        <translation>&amp;Pantalla</translation>
    </message>
    <message>
        <source>User Interface &amp;language:</source>
        <translation>&amp;Llengua de la interfície d'usuari:</translation>
    </message>
    <message>
        <source>&amp;Unit to show amounts in:</source>
        <translation>&amp;Unitats per mostrar els imports en:</translation>
    </message>
    <message>
        <source>Choose the default subdivision unit to show in the interface and when sending coins.</source>
        <translation>Selecciona la unitat de subdivisió per defecte per mostrar en la interfície quan s'envien monedes.</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;D'acord</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Cancel·la</translation>
    </message>
    <message>
        <source>default</source>
        <translation>Per defecte</translation>
    </message>
    <message>
        <source>The supplied proxy address is invalid.</source>
        <translation>L'adreça proxy introduïda és invalida.</translation>
    </message>
    </context>
<context>
    <name>OverviewPage</name>
    <message>
        <source>Form</source>
        <translation>Formulari</translation>
    </message>
    <message>
        <source>Available:</source>
        <translation>Disponible:</translation>
    </message>
    <message>
        <source>Your current spendable balance</source>
        <translation>El balanç que podeu gastar actualment</translation>
    </message>
    <message>
        <source>Immature:</source>
        <translation>Immadur:</translation>
    </message>
    <message>
        <source>Your current total balance</source>
        <translation>El balanç total actual</translation>
    </message>
    </context>
<context>
    <name>QObject</name>
    <message numerus="yes">
        <source>%n second(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n day(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n week(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n year(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>RPCConsole</name>
    <message>
        <source>Client version</source>
        <translation>Versió del client</translation>
    </message>
    <message>
        <source>&amp;Information</source>
        <translation>&amp;Informació</translation>
    </message>
    <message>
        <source>Startup time</source>
        <translation>&amp;Temps d'inici</translation>
    </message>
    <message>
        <source>Number of connections</source>
        <translation>Nombre de connexions</translation>
    </message>
    <message>
        <source>Block chain</source>
        <translation>Cadena de blocs</translation>
    </message>
    <message>
        <source>Current number of blocks</source>
        <translation>Nombre de blocs actuals</translation>
    </message>
    <message>
        <source>Last block time</source>
        <translation>Últim temps de bloc</translation>
    </message>
    <message>
        <source>&amp;Open</source>
        <translation>&amp;Obre</translation>
    </message>
    <message>
        <source>&amp;Clear</source>
        <translation>Nete&amp;ja</translation>
    </message>
    <message>
        <source>&amp;Console</source>
        <translation>&amp;Consola</translation>
    </message>
    <message>
        <source>&amp;Network Traffic</source>
        <translation>Trà&amp;nsit de la xarxa</translation>
    </message>
    <message>
        <source>In:</source>
        <translation>Dins:</translation>
    </message>
    <message>
        <source>Out:</source>
        <translation>Fora:</translation>
    </message>
    <message>
        <source>Debug log file</source>
        <translation>Fitxer de registre de depuració</translation>
    </message>
    <message>
        <source>Clear console</source>
        <translation>Neteja la consola</translation>
    </message>
    <message>
        <source>Use up and down arrows to navigate history, and &lt;b&gt;Ctrl-L&lt;/b&gt; to clear screen.</source>
        <translation>Utilitza les fletxes d'amunt i avall per navegar per l'historial, i &lt;b&gt;Ctrl-L&lt;\b&gt; per netejar la pantalla.</translation>
    </message>
    <message>
        <source>Type &lt;b&gt;help&lt;/b&gt; for an overview of available commands.</source>
        <translation>Escriviu &lt;b&gt;help&lt;\b&gt; per a obtenir un llistat de les ordres disponibles.</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Send Coins</source>
        <translation>Envia monedes</translation>
    </message>
    <message>
        <source>Inputs...</source>
        <translation>Entrades...</translation>
    </message>
    <message>
        <source>automatically selected</source>
        <translation>seleccionat automàticament</translation>
    </message>
    <message>
        <source>Insufficient funds!</source>
        <translation>Fons insuficients!</translation>
    </message>
    <message>
        <source>Quantity:</source>
        <translation>Quantitat:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>Import:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation>Comissió:</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation>Comissió posterior:</translation>
    </message>
    <message>
        <source>Send to multiple recipients at once</source>
        <translation>Envia a múltiples destinataris al mateix temps</translation>
    </message>
    <message>
        <source>Add &amp;Recipient</source>
        <translation>Afegeix &amp;destinatari</translation>
    </message>
    <message>
        <source>Clear &amp;All</source>
        <translation>Neteja-ho &amp;tot</translation>
    </message>
    <message>
        <source>Confirm the send action</source>
        <translation>Confirma l'acció d'enviament</translation>
    </message>
    <message>
        <source>S&amp;end</source>
        <translation>E&amp;nvia</translation>
    </message>
    <message>
        <source>Copy quantity</source>
        <translation>Copia la quantitat</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>Copia l'import</translation>
    </message>
    <message>
        <source>Copy fee</source>
        <translation>Copia la comissió</translation>
    </message>
    <message>
        <source>Copy after fee</source>
        <translation>Copia la comissió posterior</translation>
    </message>
    <message>
        <source>Copy bytes</source>
        <translation>Copia els bytes</translation>
    </message>
    <message>
        <source>Copy change</source>
        <translation>Copia el canvi</translation>
    </message>
    <message>
        <source>Confirm send coins</source>
        <translation>Confirma l'enviament de monedes</translation>
    </message>
    <message>
        <source>The amount to pay must be larger than 0.</source>
        <translation>L'import a pagar ha de ser major que 0.</translation>
    </message>
    <message>
        <source>The amount exceeds your balance.</source>
        <translation>L'import supera el vostre balanç.</translation>
    </message>
    <message>
        <source>The total exceeds your balance when the %1 transaction fee is included.</source>
        <translation>El total excedeix el vostre balanç quan s'afegeix la comissió a la transacció %1.</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(sense etiqueta)</translation>
    </message>
    </context>
<context>
    <name>SendCoinsEntry</name>
    <message>
        <source>A&amp;mount:</source>
        <translation>Q&amp;uantitat:</translation>
    </message>
    <message>
        <source>Pay &amp;To:</source>
        <translation>Paga &amp;a:</translation>
    </message>
    <message>
        <source>Message:</source>
        <translation>Missatge:</translation>
    </message>
    <message>
        <source>&amp;Label:</source>
        <translation>&amp;Etiqueta:</translation>
    </message>
    <message>
        <source>Alt+A</source>
        <translation>Alta+A</translation>
    </message>
    <message>
        <source>Paste address from clipboard</source>
        <translation>Enganxar adreça del porta-retalls</translation>
    </message>
    <message>
        <source>Enter a label for this address to add it to your address book</source>
        <translation>Introduïu una etiqueta per a aquesta adreça per afegir-la a la llibreta d'adreces</translation>
    </message>
    </context>
<context>
    <name>SignVerifyMessageDialog</name>
    <message>
        <source>Signatures - Sign / Verify a Message</source>
        <translation>Signatures - Signa / verifica un missatge</translation>
    </message>
    <message>
        <source>&amp;Sign Message</source>
        <translation>&amp;Signa el missatge</translation>
    </message>
    <message>
        <source>Alt+A</source>
        <translation>Alta+A</translation>
    </message>
    <message>
        <source>Paste address from clipboard</source>
        <translation>Enganxar adreça del porta-retalls</translation>
    </message>
    <message>
        <source>Enter the message you want to sign here</source>
        <translation>Introduïu aquí el missatge que voleu signar</translation>
    </message>
    <message>
        <source>Copy the current signature to the system clipboard</source>
        <translation>Copia la signatura actual al porta-retalls del sistema</translation>
    </message>
    <message>
        <source>Sign &amp;Message</source>
        <translation>Signa el &amp;missatge</translation>
    </message>
    <message>
        <source>Reset all sign message fields</source>
        <translation>Neteja tots els camps de clau</translation>
    </message>
    <message>
        <source>Clear &amp;All</source>
        <translation>Neteja-ho &amp;tot</translation>
    </message>
    <message>
        <source>&amp;Verify Message</source>
        <translation>&amp;Verifica el missatge</translation>
    </message>
    <message>
        <source>Reset all verify message fields</source>
        <translation>Neteja tots els camps de verificació de missatge</translation>
    </message>
    <message>
        <source>Click "Sign Message" to generate signature</source>
        <translation>Feu clic a «Signa el missatge» per a generar una signatura</translation>
    </message>
    <message>
        <source>The entered address is invalid.</source>
        <translation>L'adreça introduïda no és vàlida.</translation>
    </message>
    <message>
        <source>Please check the address and try again.</source>
        <translation>Comproveu l'adreça i torneu-ho a provar.</translation>
    </message>
    <message>
        <source>The entered address does not refer to a key.</source>
        <translation>L'adreça introduïda no referencia a cap clau.</translation>
    </message>
    <message>
        <source>Wallet unlock was cancelled.</source>
        <translation>El desbloqueig del moneder ha estat cancelat.</translation>
    </message>
    <message>
        <source>Private key for the entered address is not available.</source>
        <translation>La clau privada per a la adreça introduïda no està disponible.</translation>
    </message>
    <message>
        <source>Message signing failed.</source>
        <translation>La signatura del missatge ha fallat.</translation>
    </message>
    <message>
        <source>Message signed.</source>
        <translation>Missatge signat.</translation>
    </message>
    <message>
        <source>The signature could not be decoded.</source>
        <translation>La signatura no s'ha pogut descodificar.</translation>
    </message>
    <message>
        <source>Please check the signature and try again.</source>
        <translation>Comproveu la signatura i torneu-ho a provar.</translation>
    </message>
    <message>
        <source>The signature did not match the message digest.</source>
        <translation>La signatura no coincideix amb el resum del missatge.</translation>
    </message>
    <message>
        <source>Message verification failed.</source>
        <translation>Ha fallat la verificació del missatge.</translation>
    </message>
    <message>
        <source>Message verified.</source>
        <translation>Missatge verificat.</translation>
    </message>
</context>
<context>
    <name>TransactionDesc</name>
    <message numerus="yes">
        <source>Open for %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Open until %1</source>
        <translation>Obert fins %1</translation>
    </message>
    <message>
        <source>%1/offline</source>
        <translation>%1/fora de línia</translation>
    </message>
    <message>
        <source>%1/unconfirmed</source>
        <translation>%1/sense confirmar</translation>
    </message>
    <message>
        <source>%1 confirmations</source>
        <translation>%1 confirmacions</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Estat</translation>
    </message>
    <message>
        <source>, has not been successfully broadcast yet</source>
        <translation>, encara no ha estat emès correctement</translation>
    </message>
    <message numerus="yes">
        <source>, broadcast through %n node(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Data</translation>
    </message>
    <message>
        <source>Source</source>
        <translation>Font</translation>
    </message>
    <message>
        <source>From</source>
        <translation>De</translation>
    </message>
    <message>
        <source>unknown</source>
        <translation>desconegut</translation>
    </message>
    <message>
        <source>To</source>
        <translation>A</translation>
    </message>
    <message>
        <source>own address</source>
        <translation>adreça pròpia</translation>
    </message>
    <message>
        <source>label</source>
        <translation>etiqueta</translation>
    </message>
    <message>
        <source>Credit</source>
        <translation>Crèdit</translation>
    </message>
    <message numerus="yes">
        <source>matures in %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>not accepted</source>
        <translation>no acceptat</translation>
    </message>
    <message>
        <source>Debit</source>
        <translation>Dèbit</translation>
    </message>
    <message>
        <source>Transaction fee</source>
        <translation>Comissió de transacció</translation>
    </message>
    <message>
        <source>Net amount</source>
        <translation>Import net</translation>
    </message>
    <message>
        <source>Message</source>
        <translation>Missatge</translation>
    </message>
    <message>
        <source>Comment</source>
        <translation>Comentari</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Import</translation>
    </message>
    <message>
        <source>true</source>
        <translation>cert</translation>
    </message>
    <message>
        <source>false</source>
        <translation>fals</translation>
    </message>
</context>
<context>
    <name>TransactionDescDialog</name>
    <message>
        <source>This pane shows a detailed description of the transaction</source>
        <translation>Aquest panell mostra una descripció detallada de la transacció</translation>
    </message>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message>
        <source>Date</source>
        <translation>Data</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Tipus</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Adreça</translation>
    </message>
    <message numerus="yes">
        <source>Open for %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Open until %1</source>
        <translation>Obert fins %1</translation>
    </message>
    <message>
        <source>Offline</source>
        <translation>Fora de línia</translation>
    </message>
    <message>
        <source>Unconfirmed</source>
        <translation>Sense confirmar</translation>
    </message>
    <message>
        <source>Confirmed (%1 confirmations)</source>
        <translation>Confirmat (%1 confirmacions)</translation>
    </message>
    <message>
        <source>Conflicted</source>
        <translation>En conflicte</translation>
    </message>
    <message>
        <source>Generated but not accepted</source>
        <translation>Generat però no acceptat</translation>
    </message>
    <message>
        <source>Received with</source>
        <translation>Rebuda amb</translation>
    </message>
    <message>
        <source>Received from</source>
        <translation>Rebuda de</translation>
    </message>
    <message>
        <source>Sent to</source>
        <translation>Enviada a</translation>
    </message>
    <message>
        <source>Payment to yourself</source>
        <translation>Pagament a un mateix</translation>
    </message>
    <message>
        <source>Transaction status. Hover over this field to show number of confirmations.</source>
        <translation>Estat de la transacció. Desplaceu-vos sobre aquest camp per mostrar el nombre de confirmacions.</translation>
    </message>
    <message>
        <source>Date and time that the transaction was received.</source>
        <translation>Data i hora en que la transacció va ser rebuda.</translation>
    </message>
    <message>
        <source>Type of transaction.</source>
        <translation>Tipus de transacció.</translation>
    </message>
    <message>
        <source>Amount removed from or added to balance.</source>
        <translation>Import extret o afegit del balanç.</translation>
    </message>
</context>
<context>
    <name>TransactionView</name>
    <message>
        <source>Today</source>
        <translation>Avui</translation>
    </message>
    <message>
        <source>This week</source>
        <translation>Aquesta setmana</translation>
    </message>
    <message>
        <source>This month</source>
        <translation>Aquest mes</translation>
    </message>
    <message>
        <source>Last month</source>
        <translation>El mes passat</translation>
    </message>
    <message>
        <source>This year</source>
        <translation>Enguany</translation>
    </message>
    <message>
        <source>Range...</source>
        <translation>Rang...</translation>
    </message>
    <message>
        <source>Received with</source>
        <translation>Rebuda amb</translation>
    </message>
    <message>
        <source>Sent to</source>
        <translation>Enviada a</translation>
    </message>
    <message>
        <source>To yourself</source>
        <translation>A un mateix</translation>
    </message>
    <message>
        <source>Mined</source>
        <translation>Minada</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>Altres</translation>
    </message>
    <message>
        <source>Min amount</source>
        <translation>Import mínim</translation>
    </message>
    <message>
        <source>Copy address</source>
        <translation>Copia l'adreça</translation>
    </message>
    <message>
        <source>Copy label</source>
        <translation>Copia l'etiqueta</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>Copia l'import</translation>
    </message>
    <message>
        <source>Copy transaction ID</source>
        <translation>Copia l'ID de transacció</translation>
    </message>
    <message>
        <source>Edit label</source>
        <translation>Editar etiqueta</translation>
    </message>
    <message>
        <source>Show transaction details</source>
        <translation>Mostra detalls de la transacció</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>Confirmat</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Data</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Tipus</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Etiqueta</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Adreça</translation>
    </message>
    <message>
        <source>Range:</source>
        <translation>Rang:</translation>
    </message>
    <message>
        <source>to</source>
        <translation>a</translation>
    </message>
</context>
<context>
    <name>bitcoin-core</name>
    <message>
        <source>Failed to listen on any port. Use -listen=0 if you want this.</source>
        <translation>Ha fallat escoltar a qualsevol port. Feu servir -listen=0 si voleu fer això.</translation>
    </message>
    <message>
        <source>Invalid -proxy address: '%s'</source>
        <translation>Adreça -proxy invalida: '%s'</translation>
    </message>
    <message>
        <source>Loading addresses...</source>
        <translation>S'estan carregant les adreces...</translation>
    </message>
    <message>
        <source>Unknown network specified in -onlynet: '%s'</source>
        <translation>Xarxa desconeguda especificada a -onlynet: '%s'</translation>
    </message>
    <message>
        <source>Insufficient funds</source>
        <translation>Balanç insuficient</translation>
    </message>
    <message>
        <source>Loading block index...</source>
        <translation>S'està carregant l'índex de blocs...</translation>
    </message>
    <message>
        <source>Loading wallet...</source>
        <translation>S'està carregant el moneder...</translation>
    </message>
    <message>
        <source>Cannot write default address</source>
        <translation>No es pot escriure l'adreça per defecte</translation>
    </message>
    <message>
        <source>Rescanning...</source>
        <translation>S'està reescanejant...</translation>
    </message>
    <message>
        <source>Done loading</source>
        <translation>Ha acabat la càrrega</translation>
    </message>
    </context>
</TS>